@@ -18,14 +18,16 @@ from pythautomata.tests.test_pdfa_operations import TestPDFAOperations
 from pythautomata.tests.test_pdfa_last_token_queries import TestPDFALastTokenQueries
 from pythautomata.tests.test_dfa_to_moore_machine import TestDFAToMooreMachine
 from pythautomata.tests.test_dfa_exporting import TestDFAExporting
+from pythautomata.tests.test_dfa_loading import TestDFALoading
 
 
 def get_all_tests():
-    return [TestDFAExporting, TestSimpleDFAGenerator, TestMinimizer, TestAutomataConvertor,
-            TestDFAGenerators, TestAutomataComparison, TestSequence, TestDFAOperations,
-            TestAutomataDefinitions, TestPDFAGenerator, TestRegexGenerator, TestPDFASerialization,
-            TestDFASerialization, TestPDFAMetrics, TestPDFAOperations, TestPDFALastTokenQueries,
-            TestMooreMachinesLastSymbolQueries, TestDFAToMooreMachine]
+    return [TestDFALoading]
+    # , TestDFAExporting, TestSimpleDFAGenerator, TestMinimizer, TestAutomataConvertor,
+    #         TestDFAGenerators, TestAutomataComparison, TestSequence, TestDFAOperations,
+    #         TestAutomataDefinitions, TestPDFAGenerator, TestRegexGenerator, TestPDFASerialization,
+    #         TestDFASerialization, TestPDFAMetrics, TestPDFAOperations, TestPDFALastTokenQueries,
+    #         TestMooreMachinesLastSymbolQueries, TestDFAToMooreMachine]
 
 
 def run():
